@@ -1,5 +1,6 @@
 <?php
-/* $Id: danish-iso-8859-1.inc.php,v 2.44 2004/09/26 01:23:45  */
+/* $Id: danish-iso-8859-1.inc.php,v 2.93 2005/08/18 09:58:59 lem9 Exp $ */
+/* Dansk v 2.92 18/8-2005 00:00:00 - overstter AlleyKat kan kontaktes p < phpmyadmin (at) phpbb2.dk > */
 
 $charset = 'iso-8859-1';
 $text_dir = 'ltr';
@@ -11,13 +12,13 @@ $number_decimal_separator = ',';
 $byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
 
 $day_of_week = array('sn', 'man', 'tir', 'ons', 'tor', 'fre', 'lr');
-$month = array('Jan', 'Feb', 'Mar', 'Apr', 'Maj', 'Jun', 'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Dec');
+$month = array('jan', 'feb', 'mar', 'apr', 'maj', 'jun', 'jul', 'aug', 'sep', 'okt', 'nov', 'dec');
 // Se http://www.php.net/manual/en/function.strftime.php
 // for at definere variablen herunder
 $datefmt = '%d/%m %Y kl. %H:%M:%S';
 $timespanfmt = '%s dage, %s timer, %s minutter og %s sekunder';
 
-$strAPrimaryKey = 'Der er fjet en primr ngle til %s';
+$strAPrimaryKey = 'En primr ngle er blevet tilfjet til %s';
 $strAbortedClients = 'Afbrudt';
 $strAbsolutePathToDocSqlDir = 'Indtast venligst absolut sti p webserveren til docSQL mappen';
 $strAccessDenied = 'Adgang Ngtet';
@@ -28,6 +29,7 @@ $strAddConstraints = 'Tilfj begrnsninger';
 $strAddDeleteColumn = 'Tilfj/Slet felt-kolonne';
 $strAddDeleteRow = 'Tilfj/Slet kriterie-rkke';
 $strAddDropDatabase = 'Tilfj DROP DATABASE';
+$strAddFields = 'Tilfj %s felt(er)';
 $strAddHeaderComment = 'Tilfj tilpassede kommentarer i headeren (\\n deler linjer)';
 $strAddIfNotExists = 'Tilfj IF NOT EXISTS';
 $strAddIntoComments = 'Tilfj til kommentarer';
@@ -38,13 +40,14 @@ $strAddSearchConditions = 'Tilfj sgekriterier (kroppen af "WHERE" stningen):';
 $strAddToIndex = 'Fj til indeks &nbsp;%s&nbsp;kolonne(r)';
 $strAddUser = 'Tilfj en ny bruger';
 $strAddUserMessage = 'Du har tilfjet en ny bruger.';
-$strAddedColumnComment = 'Tilfjet kommentar for kolonne';
-$strAddedColumnRelation = 'Tilfjet relation for kolonne';
+$strAddedColumnComment = 'Tilfjet kommentar til kolonne';
+$strAddedColumnRelation = 'Tilfjet relation til kolonne';
 $strAdministration = 'Administration';
 $strAffectedRows = 'Berrte rkker:';
 $strAfter = 'Efter %s';
 $strAfterInsertBack = 'Retur';
 $strAfterInsertNewInsert = 'Indst en ny record';
+$strAfterInsertNext = "Redigr nste rkke";
 $strAfterInsertSame = 'G tilbage til denne side';
 $strAll = 'Alle';
 $strAllTableSameWidth = 'vis alle tabeller med samme bredde?';
@@ -52,9 +55,11 @@ $strAlterOrderBy = 'Arranger rkkeorden efter';
 $strAnIndex = 'Der er tilfjet et indeks til %s';
 $strAnalyzeTable = 'Analyser tabel';
 $strAnd = 'Og';
+$strAndThen = "og s";
 $strAny = 'Enhver';
 $strAnyHost = 'Enhver vrt';
 $strAnyUser = 'Enhver bruger';
+$strApproximateCount = 'Kan vre anslet. Se FAQ 3.11';
 $strArabic = 'Arabisk';
 $strArmenian = 'Armensk';
 $strAscending = 'Stigende';
@@ -68,8 +73,15 @@ $strBack = 'Tilbage';
 $strBaltic = 'Baltisk';
 $strBeginCut = 'BEGYND KLIP';
 $strBeginRaw = 'BEGYND R';
+$strBinLogEventType = 'Hndelsestype';
+$strBinLogInfo = 'Information';
+$strBinLogName = 'Lognavn';
+$strBinLogOriginalPosition = 'Original position';
+$strBinLogPosition = 'Position';
+$strBinLogServerId = 'Server ID';
 $strBinary = ' Binrt ';
 $strBinaryDoNotEdit = ' Binrt - m ikke ndres ';
+$strBinaryLog = 'Binr log';
 $strBookmarkAllUsers = 'Lad alle brugere f adgang til bogmrket';
 $strBookmarkDeleted = 'Bogmrket er fjernet.';
 $strBookmarkLabel = 'Mrke';
@@ -79,7 +91,15 @@ $strBookmarkThis = 'Lav bogmrke til denne SQL-foresprgsel';
 $strBookmarkView = 'Kun oversigt';
 $strBrowse = 'Vis';
 $strBrowseForeignValues = 'Bladr i udenlandske vrdier';
+$strBufferPool = 'Buffer Pool';
+$strBufferPoolActivity = 'Buffer Pool Aktivitet';
+$strBufferPoolUsage = 'Buffer Pool Forbrug';
+$strBufferReadMisses = 'Read misses';
+$strBufferReadMissesInPercent = 'Read misses i %';
+$strBufferWriteWaits = 'Write waits';
+$strBufferWriteWaitsInPercent = 'Write waits i %';
 $strBulgarian = 'Bulgarsk';
+$strBusyPages = 'Travle sider';
 $strBzError = 'phpMyAdmin kunne ikke komprimere dumpet pga. en delagt Bz2-udvidelse i denne php-version. Det anbefales strkt at stte <code>$cfg[\'BZipDump\']</code>-direktivet i din phpMyAdmin-konfigurationsfil til <code>FALSE</code>. Hvis du vil bruge Bz2-komprimeringsudvidelser, br du opdatere til en nyere php version. Se php bug report %s for detaljer.';
 $strBzip = '"bzipped"';
 
@@ -109,7 +129,7 @@ $strCharsetOfFile = 'Tegnst for filen:';
 $strCharsets = 'Tegnst';
 $strCharsetsAndCollations = 'Tegnst og kollationer (Collations)';
 $strCheckAll = 'Afmrk alt';
-$strCheckOverhead = 'Markr tabeller med overhead';
+$strCheckOverhead = 'Check tabeller der har overhead';
 $strCheckPrivs = 'Check Privilegier';
 $strCheckPrivsLong = 'Check privilegier for database &quot;%s&quot;.';
 $strCheckTable = 'Tjek tabel';
@@ -121,6 +141,7 @@ $strColumnPrivileges = 'Kolonne-specifikke privilegier';
 $strCommand = 'Kommando';
 $strComments = 'Kommentarer';
 $strCommentsForTable = 'COMMENTS FOR TABLE (tabel-kommentarer)';
+$strCompatibleHashing = 'MySQL&nbsp;4.0 kompatibel';
 $strCompleteInserts = 'Lav komplette inserts';
 $strCompression = 'Komprimering';
 $strConfigFileError = 'phpMyAdmin kunne ikke lse din konfigurationsfil!<br />Dette kan ske hvis php finder en parser-fejl i den, eller php kan ikke finde filen.<br />Kald konfigurationsfilen direkte fra nedenstende link og ls de(n) phpfejlmeddelse(r) du fr. I de fleste tilflde mangler der et anfrselstegn eller et semikolon et sted.<br />Hvis du fr en blank side, er alt i orden.';
@@ -130,11 +151,14 @@ $strConnections = 'Forbindelser';
 $strConstraintsForDumped = 'Begrnsninger for dumpede tabeller';
 $strConstraintsForTable = 'Begrnsninger for tabel';
 $strCookiesRequired = 'Herefter skal cookies vre sat til.';
+$strCopy = 'Kopi';
+$strCopyDatabaseOK = 'Database %s er blevet kopieret til %s';
 $strCopyTable = 'Kopier tabel til (database<b>.</b>tabel):';
 $strCopyTableOK = 'Tabellen %s er nu kopieret til: %s.';
 $strCopyTableSameNames = 'Kan ikke kopiere tabellen til den samme!';
 $strCouldNotKill = 'phpMyAdmin kunne ikke drbe trden %s. Den er sandsynligvis allerede lukket.';
 $strCreate = 'Opret';
+$strCreateDatabaseBeforeCopying = 'CREATE DATABASE fr kopiering';
 $strCreateIndex = 'Dan et indeks p&nbsp;%s&nbsp;kolonner';
 $strCreateIndexTopic = 'Lav et nyt indeks';
 $strCreateNewDatabase = 'Opret ny database';
@@ -149,6 +173,7 @@ $strCzech = 'Tjekkisk';
 $strCzechSlovak = 'Tjekkisk-Slovakisk';
 
 $strDBComment = 'Databasekommentar: ';
+$strDBCopy = 'Kopir database til';
 $strDBGContext = 'Sammenhng';
 $strDBGContextID = 'Sammenhng-ID';
 $strDBGHits = 'Hits';
@@ -163,6 +188,7 @@ $strDanish = 'Dansk';
 $strData = 'Data';
 $strDataDict = 'Data Dictionary';
 $strDataOnly = 'Kun data';
+$strDataPages = 'Sider der indeholder data';
 $strDatabase = 'Database';
 $strDatabaseEmpty = 'Databasenavnet er tomt!';
 $strDatabaseExportOptions = 'Database eksportindstillinger';
@@ -177,6 +203,7 @@ $strDatabasesStatsHeavyTraffic = 'Bemrk: At sl databasestatistikkerne til her ka
 $strDbPrivileges = 'Database-specifikke privilegier';
 $strDbSpecific = 'database-specifik';
 $strDefault = 'Standardvrdi';
+$strDefaultEngine = '%s er standard datalageret p denne MySQL-server.';
 $strDefaultValueHelp = 'For standardvrdier, indtast venligst kun en enkelt vrdi, uden backslash escaping eller quotes, ud fra flgende format: a';
 $strDefragment = 'Defragmentr tabel';
 $strDelOld = 'Nuvrende side har referencer til tabeller der ikke lngere eksisterer. Vil du slette disse referencer?';
@@ -190,6 +217,7 @@ $strDeleting = 'Sletter %s';
 $strDescending = 'Faldende';
 $strDescription = 'Beskrivelse';
 $strDictionary = 'ordbog';
+$strDirtyPages = 'Beskidte sider';
 $strDisableForeignChecks = 'Sl fremmedngle-checks fra';
 $strDisabled = 'Slet fra';
 $strDisplayFeat = 'Vis muligheder';
@@ -218,9 +246,14 @@ $strEncloseInTransaction = 'Inkludr eksport i en transaktion';
 $strEnd = 'Slut';
 $strEndCut = 'SLUT KLIP';
 $strEndRaw = 'SLUT R';
+$strEngineAvailable = '%s er tilgngelig p denne MySQL-server.';
+$strEngineDisabled = '%s er slet fra p denne MySQL-server.';
+$strEngineUnsupported = 'Denne MySQL-server understtter ikke %s datalager.';
+$strEngines = 'Lagre';
 $strEnglish = 'Engelsk';
 $strEnglishPrivileges = ' NB: Navne p MySQL privilegier er p engelsk ';
 $strError = 'Fejl';
+$strEscapeWildcards = 'Jokertegn _ og % skal vre escaped med en \ foran for at bruge dem bogstaveligt';
 $strEstonian = 'Estisk';
 $strExcelEdition = 'Excel-udgave';
 $strExcelOptions = 'Excel-indstillinger';
@@ -248,12 +281,15 @@ $strFlushPrivilegesNote = 'Bemrk: phpMyAdmin henter brugernes privilegier direkt
 $strFlushTable = 'Flush tabellen ("FLUSH")';
 $strFormEmpty = 'Ingen vrdi i formularen !';
 $strFormat = 'Format';
+$strFreePages = 'Frie sider';
 $strFullText = 'Komplette tekster';
 $strFunction = 'Funktion';
 
 $strGenBy = 'Genereret af';
 $strGenTime = 'Genereringstid';
 $strGeneralRelationFeat = 'Generelle relationsmuligheder';
+$strGenerate = 'Generr';
+$strGeneratePassword = 'Generr Kodeord';
 $strGeorgian = 'Georgisk';
 $strGerman = 'Tysk';
 $strGlobal = 'global';
@@ -264,6 +300,10 @@ $strGrantOption = 'Tildel';
 $strGreek = 'Grsk';
 $strGzip = '"gzipped"';
 
+$strHTMLExcel = 'Microsoft Excel 2000';
+$strHTMLExcelOptions = 'Microsoft Excel 2000 eksportindstillinger';
+$strHTMLWord = 'Microsoft Word 2000';
+$strHTMLWordOptions = 'Microsoft Word 2000 eksportindstillinger';
 $strHasBeenAltered = 'er ndret.';
 $strHasBeenCreated = 'er oprettet.';
 $strHaveToShow = 'Du skal vlge mindst en kolonne der skal vises';
@@ -276,7 +316,7 @@ $strHostEmpty = 'Der er intet vrtsnavn!';
 $strHungarian = 'Ungarsk';
 
 $strIcelandic = 'Islandsk';
-$strId = 'ID'; 
+$strId = 'ID';
 $strIdxFulltext = 'Fuldtekst';
 $strIfYouWish = 'Hvis du kun nsker at importere nogle af tabellens kolonner, angives de med en kommasepareret felt liste.';
 $strIgnore = 'Ignorer';
@@ -290,11 +330,24 @@ $strIndex = 'Indeks';
 $strIndexHasBeenDropped = 'Indeks %s er blevet slettet';
 $strIndexName = 'Indeksnavn&nbsp;:';
 $strIndexType = 'Indekstype&nbsp;:';
-$strIndexes = 'Indekser';
+$strIndexWarningMultiple = 'Mere end en %s ngle blev skabt for kolonne `%s`';
+$strIndexWarningPrimary = 'PRIMARY og INDEX ngler burde ikke begge vre sat for kolonne `%s`';
+$strIndexWarningTable = 'Problemer med indeksene p tabel `%s`';
+$strIndexWarningUnique = 'UNIQUE og INDEX ngler burde ikke begge vre sat for kolonne `%s`';
+$strIndexes = 'Indeks';
+$strInnoDBAutoextendIncrement = 'Autoextend forgelse';
+$strInnoDBAutoextendIncrementDesc = ' Strrelsen p den udvidelse der vil forekomme, nr pladsen i en autoudvidende tabel udvides fordi den lber fuld.';
+$strInnoDBBufferPoolSize = 'Buffer pool strrelse';
+$strInnoDBBufferPoolSizeDesc = 'Strrelse p memorybufferen InnoDB bruger til at cache data og indeks p dets tabeller.';
+$strInnoDBDataFilePath = 'Datafiler';
+$strInnoDBDataHomeDir = 'Data hovedmappe';
+$strInnoDBDataHomeDirDesc = 'Den flles del af stien til mappen med alle InnoDB datafiler.';
+$strInnoDBPages = 'sider';
 $strInnodbStat = 'InnoDB status';
 $strInsecureMySQL = 'Din konfigurationsfil indeholder indstillinger (root og uden kodeord) som svarer til en standard MySQL priviligeret brugerkonto. Din MySQL server krer med denne standardindstilling, <u>er ben for indtrngen</u>, og du br virkelig gre noget ved dette sikkerhedshul.';
 $strInsert = 'Indst';
 $strInsertAsNewRow = 'Indst som ny rkke';
+$strInsertBookmarkTitle = 'Indst venligst bogmrke-titel';
 $strInsertNewRow = 'Indst ny rkke';
 $strInsertTextfiles = 'Importer tekstfil til tabellen';
 $strInsertedRowId = 'Indsat rkke-id:';
@@ -302,6 +355,10 @@ $strInsertedRows = 'Indsatte rkker:';
 $strInstructions = 'Instruktioner';
 $strInternalNotNecessary = '* En intern relation er ikke ndvendig nr den ogs eksisterer i InnoDB.';
 $strInternalRelations = 'Interne relationer';
+$strInvalidColumnCount = 'Kolonnetlling skal vre strre end nul.';
+$strInvalidFieldAddCount = 'Du skal tilfje mindst t felt.';
+$strInvalidFieldCount = 'Tabellen skal indeholde mindst t felt.';
+$strInvalidRowNumber = '%d er ikke gyldigt rkkenummer.';
 
 $strJapanese = 'Japansk';
 $strJumpToDB = 'Hop til database &quot;%s&quot;.';
@@ -316,6 +373,7 @@ $strKorean = 'Koreansk';
 $strLaTeX = 'LaTeX';
 $strLaTeXOptions = 'LaTeX indstillinger';
 $strLandscape = 'Liggende';
+$strLatchedPages = 'Eksklusivt lste (latched) sider';
 $strLatexCaption = 'Tabeloverskrift';
 $strLatexContent = 'Indhold af tabel __TABLE__';
 $strLatexContinued = '(fortsttes)';
@@ -341,6 +399,7 @@ $strLogUsername = 'Brugernavn:';
 $strLogin = 'Login';
 $strLoginInformation = 'Login-information';
 $strLogout = 'Log af';
+$strLongOperation = 'Denne operation kan tage lang tid. Fortst alligevel?';
 
 $strMIMETypesForTable = 'MIME TYPES FOR TABLE (MIME-typer for tabellen)';
 $strMIME_MIMEtype = 'MIME-type';
@@ -354,6 +413,8 @@ $strMIME_transformation_options = 'Transformationsindstillinger';
 $strMIME_transformation_options_note = 'Indtast vrdier for transformationsindstillinger ud fra flgende format: \'a\',\'b\',\'c\'...<br />Skulle du f brug for at indstte en backslash ("\") eller en apostrof ("\'") i vrdierne, backslash det (for eksempel \'\\\\xyz\' eller \'a\\\'b\').';
 $strMIME_without = 'MIME-typer skrevet med kursiv har ikke en separat transformationsfunktion';
 $strMaximumSize = 'Maksimum strrelse: %s%s';
+$strMbExtensionMissing = "PHP-udvidelsen mbstring blev ikke fundet og du ser ud til at bruge et multibyte tegnst. Uden mbstring-udvidelsen er phpMyAdmin ude af stand til at opdele  strenge korrekt og dette kan forrsage uventede resultater.";
+$strMbOverloadWarning = "Du har mbstring.func_overload slet til i din PHP-konfiguration. Denne indstilling er ikke kompatibel med phpMyAdmin og kan forrsage delggelse af nogle data!";
 $strModifications = 'Rettelserne er gemt!';
 $strModify = 'Ret';
 $strModifyIndexTopic = 'ndring af et indeks';
@@ -363,6 +424,18 @@ $strMoveTableOK = 'Tabel %s er flyttet til %s.';
 $strMoveTableSameNames = 'Kan ikke flytte tabellen til den samme!';
 $strMultilingual = 'flersproget';
 $strMustSelectFile = 'Vlg en fil du vil indstte.';
+$strMyISAMDataPointerSize = 'Data pointer strrelse';
+$strMyISAMDataPointerSizeDesc = 'Standard pointerstrrelse i bytes, til brug ved CREATE TABLE for MyISAM tabeller nr der ikke er specificeret nogen MAX_ROWS indstilling.';
+$strMyISAMMaxExtraSortFileSize = 'Maksimal strrelse for midlertidige filer ved oprettelse af indeks';
+$strMyISAMMaxExtraSortFileSizeDesc = 'Hvis den midlertidige fil der bruges til hurtig MyISAM indeks-oprettelse ville vre strre end ved brug af key cache med strrelsen angivet her, foretrk key cache-metoden.';
+$strMyISAMMaxSortFileSize = 'Maksimal strrelse for midlertidige sorteringsfiler';
+$strMyISAMMaxSortFileSizeDesc = 'Maksimal strrelse for den midlertidige fil MySQL har lov til at bruge under genetablering af et MyISAM indeks (under REPAIR TABLE, ALTER TABLE, eller LOAD DATA INFILE).';
+$strMyISAMRecoverOptions = 'Automatisk genopretnings-modus';
+$strMyISAMRecoverOptionsDesc = 'Modus for automatisk genetablering af crashede MyISAM tabeller, som sat via --myisam-recover server opstartsindstillingen.';
+$strMyISAMRepairThreads = 'Reparr trde';
+$strMyISAMRepairThreadsDesc = 'Hvis denne vrdi er strre end 1, oprettes MyISAM tabel-indeks parallelt (hvert indeks i dets egen trd) under Reparation ved sortering-processen.';
+$strMyISAMSortBufferSize = 'Sorterings-bufferstrrelse';
+$strMyISAMSortBufferSizeDesc = 'Bufferen der allokeres ved sortering af MyISAM indeks under en REPAIR TABLE eller nr indeks oprettes med CREATE INDEX eller ALTER TABLE.';
 $strMySQLCharset = 'MySQL Tegnst';
 $strMySQLConnectionCollation = 'MySQL forbindelses-sammenkring';
 $strMySQLReloaded = 'MySQL genstartet.';
@@ -376,9 +449,11 @@ $strName = 'Navn';
 $strNeedPrimaryKey = 'Du burde definere en primr ngle for denne tabel.';
 $strNext = 'Nste';
 $strNo = 'Nej';
+$strNoActivity = 'Ingen aktivitet i de seneste %s sekunder eller mere, log venligst ind igen';
 $strNoDatabases = 'Ingen databaser';
 $strNoDatabasesSelected = 'Ingen databaser valgt.';
 $strNoDescription = 'ingen beskrivelse';
+$strNoDetailsForEngine = 'Der er ingen detaljerede statusinformationer tilgngelige for dette datalager.';
 $strNoDropDatabases = '"DROP DATABASE" erklringer kan ikke bruges.';
 $strNoExplain = 'Spring over Forklar SQL';
 $strNoFrames = 'phpMyAdmin er mere brugervenlig med en browser, der kan klare <b>frames</b>.';
@@ -395,17 +470,18 @@ $strNoRights = 'Du har ikke tilstrkkelige rettigheder til at vre her!';
 $strNoRowsSelected = 'Ingen rkker valgt';
 $strNoSpace = 'Utilstrkkeligt plads til at gemme filen %s.';
 $strNoTablesFound = 'Ingen tabeller fundet i databasen.';
+$strNoThemeSupport = 'Ingen tema/layout-understttelse, tjek venligst din konfiguration og/eller dine temaer i mappen %s.';
 $strNoUsersFound = 'Ingen bruger(e) fundet.';
 $strNoValidateSQL = 'Spring over Validr SQL';
 $strNone = 'Intet';
 $strNotNumber = 'Dette er ikke et tal!';
 $strNotOK = 'ikke OK';
 $strNotSet = 'Tabel <b>%s</b> findes ikke eller er ikke sat i %s';
-$strNotValidNumber = ' er ikke et gyldigt rkkenummer!';
 $strNull = 'Nulvrdi';
 $strNumSearchResultsInTable = '%s hit(s) i tabel <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> hit(s)';
 $strNumTables = 'Tabeller';
+$strNumberOfFields = 'Antal felter';
 
 $strOK = 'OK';
 $strOftenQuotation = 'Ofte anfrselstegn. OPTIONALLY betyder at kun char og varchar felter er omsluttet med det valgte "tekstkvalifikator"-tegn.'; //skal muligvis ndres
@@ -421,11 +497,13 @@ $strOverwriteExisting = 'Overskriv eksisterende fil(er)';
 $strPHP40203 = 'Du bruger PHP 4.2.3, som har en alvorlig fejl med multi-byte strenge (mbstring). Se PHP bug report 19404. Denne version af PHP kan ikke anbefales at bruge med phpMyAdmin.';
 $strPHPVersion = 'PHP version';
 $strPageNumber = 'Side nummer:';
+$strPagesToBeFlushed = 'Sider der str til at blive tmt';
 $strPaperSize = 'Papirstrrelse';
 $strPartialText = 'Delvise tekster';
 $strPassword = 'Kodeord';
 $strPasswordChanged = 'Kodeordet for %s blev korrekt udskiftet.';
 $strPasswordEmpty = 'Der er ikke angivet noget kodeord!';
+$strPasswordHashing = 'Kodeord Hashing'; // may be better
 $strPasswordNotSame = 'De to kodeord er ikke ens!';
 $strPdfDbSchema = 'Skematik for databasen "%s" - Side %s';
 $strPdfInvalidTblName = 'Tabellen "%s" findes ikke!';
@@ -451,13 +529,19 @@ $strPrintView = 'Vis (udskriftvenlig)';
 $strPrintViewFull = 'Udskrift-visning (med fulde tekster)';
 $strPrivDescAllPrivileges = 'Inkluderer alle privilegier pnr GRANT.';
 $strPrivDescAlter = 'Tillader ndring af strukturen p eksisterende tabeller.';
+$strPrivDescAlterDb = 'Tillader ndring af strukturen p eksisterende tabeller svel som ndring af standard tegnst og kollation af databaser.';
+$strPrivDescAlterRoutine = 'Tillader ndring og sletning af gemte rutiner.';
 $strPrivDescCreateDb = 'Tillader oprettelse af nye databaser og tabeller.';
+$strPrivDescCreateRoutine = 'Tillader oprettelse af gemte rutiner.';
 $strPrivDescCreateTbl = 'Tillader oprettelse af nye tabeller.';
 $strPrivDescCreateTmpTable = 'Tillader oprettelse af midlertidige tabeller.';
+$strPrivDescCreateUser = 'Tillader oprettelse, sletning og omdbning af brugerkonti.';
+$strPrivDescCreateView = 'Tillader oprettelse af nye Allows creating new views.';
 $strPrivDescDelete = 'Tillader sletning af data.';
 $strPrivDescDropDb = 'Tillader at droppe databaser og tabeller.';
 $strPrivDescDropTbl = 'Tillader at droppe tabeller.';
 $strPrivDescExecute = 'Tillader krsel af gemte procedurer; Har ingen effekt i denne MySQL-version.';
+$strPrivDescExecute5 = 'Tillader udfrelse af gemte rutiner.';
 $strPrivDescFile = 'Tillader import af data fra og eksport af data til filer.';
 $strPrivDescGrant = 'Tillader oprettelse af brugere og privilegier uden at genindlse privilegie-tabellerne.';
 $strPrivDescIndex = 'Tillader at skabe og droppe indeks.';
@@ -474,6 +558,7 @@ $strPrivDescReplClient = 'Giver brugeren rettigheder til at sprge hvor Slaves /
 $strPrivDescReplSlave = 'Ndvendigt for replikationsslaverne.';
 $strPrivDescSelect = 'Tillader lsning af data.';
 $strPrivDescShowDb = 'Giver adgang til den fuldstndige liste over databaser.';
+$strPrivDescShowView = 'Tillader udfrelse af SHOW CREATE VIEW foresprgsler.';
 $strPrivDescShutdown = 'Tillader nedlukning af serveren.';
 $strPrivDescSuper = 'Tillader forbindelse, selv hvis maksimalt antal forbindelser er net; Ndvendigt for de fleste administrative operationer som indstilling af globale variabler eller for at drbe andre brugeres trde.';
 $strPrivDescUpdate = 'Tillader ndring af data.';
@@ -481,7 +566,6 @@ $strPrivDescUsage = 'Ingen privilegier.';
 $strPrivileges = 'Privilegier';
 $strPrivilegesReloaded = 'Privilegierne blev korrekt genindlst.';
 $strProcesslist = 'Procesliste';
-$strProperties = 'Egenskaber';
 $strPutColNames = 'Indst feltnavne i frste rkke';
 
 $strQBE = 'Foresp. via eks.';
@@ -496,6 +580,7 @@ $strQueryType = 'Foresprgselstype';
 $strQueryWindowLock = 'Overskriv ikke denne foresprgsel fra udenfor vinduet';
 
 $strReType = 'Skriv igen';
+$strReadRequests = 'Read-foresprgsler';
 $strReceived = 'Modtaget';
 $strRecords = 'Poster';
 $strReferentialIntegrity = 'Check reference-integriteten';
@@ -523,6 +608,7 @@ $strRevokeAndDelete = 'Tilbagekald alle aktive privileiger fra brugerne og slet
 $strRevokeAndDeleteDescr = 'Bruger(e) vil fortsat have USAGE-privilegiet indtil privilegierne genindlses.';
 $strRevokeMessage = 'Du har tilbagekaldt privilegierne for %s';
 $strRomanian = 'Rumnsk';
+$strRoutines = 'Rutiner';
 $strRowLength = 'Rkkelngde';
 $strRowSize = ' Rkkestrrelse ';
 $strRows = 'Rkker';
@@ -538,6 +624,7 @@ $strRunning = 'krer p %s';
 $strRussian = 'Russisk';
 
 $strSQL = 'SQL';
+$strSQLExportCompatibility = "SQL eksport-kompatibilitet";
 $strSQLExportType = 'Eksporttype';
 $strSQLOptions = 'SQL-indstillinger';
 $strSQLParserBugMessage = 'Det er muligt at du har fundet en fejl i SQL-parseren. Undersg venligst din foresprgsel nje, og check at anfrselstegn er rigtige og ikke giver konflikter. Andre fejlrsager kan vre at du uploader en fil med binr udenfor et lukket tekstomrde. Du kan ogs prve din foresprgsel i MySQL kommandolinje-interfacet. MySQL-serverens fejlmelding der flger herunder, hvis der er nogen, kan ogs hjlpe dig med at finde problemet. Hvis du stadig har probemer eller hvis parseren fejler hvor kommandolinjeinterfacet lykkes, reducer din SQL-foresprgselsinput til den ene foresprgsel der forrsager problemet, og indsend en fejlrapport med datablokken i KLIP-sektionen herunder:';
@@ -563,6 +650,7 @@ $strSearchType = 'Find:';
 $strSecretRequired = 'Konfigurationsfilen skal nu bruge et hemmeligt kodeord (blowfish_secret).';
 $strSelectADb = 'Vlg en database';
 $strSelectAll = 'Vlg alle';
+$strSelectBinaryLog = 'Vlg binrlog til gennemsyn';
 $strSelectFields = 'Vlg mindst eet felt:';
 $strSelectNumRows = 'i foresprgsel';
 $strSelectTables = 'Vlg Tabeller';
@@ -596,6 +684,7 @@ $strSingly = '(enkeltvis)';
 $strSize = 'Strrelse';
 $strSlovak = 'Slovakisk';
 $strSlovenian = 'Slovensk';
+$strSocketProblem = '(eller den lokale MySQL server\'s socket er ikke korrekt konfigureret)';
 $strSort = 'Sorter';
 $strSortByKey = 'Sorteringsngle';
 $strSpaceUsage = 'Pladsforbrug';
@@ -606,8 +695,10 @@ $strStatCreateTime = 'Oprettelse';
 $strStatUpdateTime = 'Sidste opdatering';
 $strStatement = 'Erklringer';
 $strStatus = 'Status';
+$strStorageEngine = 'Datalager';
+$strStorageEngines = 'Datalagre';
 $strStrucCSV = 'CSV-data';
-$strStrucData = 'Struturen og data';
+$strStrucData = 'Struktur og data';
 $strStrucDrop = 'Tilfj \'DROP TABLE\'';
 $strStrucExcelCSV = 'CSV til MS Excel-data';
 $strStrucNativeExcel = 'Fdte MS Excel-data';
@@ -618,6 +709,7 @@ $strSubmit = 'Send';
 $strSuccess = 'Din SQL-foresprgsel blev udfrt korrekt';
 $strSum = 'Sum';
 $strSwedish = 'Svensk';
+$strSwitchToDatabase = 'Skift til den kopierede database';
 $strSwitchToTable = 'Skift til den kopierede tabel';
 
 $strTable = 'Tabel';
@@ -651,6 +743,7 @@ $strTraditionalChinese = 'Traditionelt Kinesisk';
 $strTraditionalSpanish = 'Traditionelt Spansk';
 $strTraffic = 'Trafik';
 $strTransformation_application_octetstream__download = 'Viser et link til at downloade et felts binre data. Frste mulighed er filnavnet p den binre fil. Anden mulighed er et muligt feltnavn fra en tabelrkke indeholdende filnavnet. Hvis du bruger anden mulighed, er feltet til den frste mulighed ndt til at vre sat til en tom streng.';
+$strTransformation_application_octetstream__hex = 'Viser hexadecimal udgave af data.';
 $strTransformation_image_jpeg__inline = 'Viser et klikbart minibilled; indstillinger: bredde,hjde i pixel (bevarer det originale perspektiv)';
 $strTransformation_image_jpeg__link = 'Viser et link til dette billede (f.eks. direkte blob-download).';
 $strTransformation_image_png__inline = 'Se image/jpeg: inline';
@@ -659,8 +752,7 @@ $strTransformation_text_plain__external = 'KUN LINUX: Starter en ekstern applika
 $strTransformation_text_plain__formatted = 'Bevarer original formattering af feltet. Der laves ikke nogen Escaping.';
 $strTransformation_text_plain__imagelink = 'Viser et billed og et link, feltet indeholder filnavnet; frste indstilling er et prfiks som "http://domain.com/", anden indstilling er bredde i pixel, tredie er hjden.';
 $strTransformation_text_plain__link = 'Viser et link, feltet indeholder filnavnet; frste indstilling er et prfiks som "http://domain.com/", anden indstilling er en titel p linket.';
-$strTransformation_text_plain__substr = 'Viser kun en del af en streng. Frste parameter er en offset for at definere hvor outputtet af din tekst starter (Default 0). Andet parameter er en offset for hvor meget tekst der returneres. Hvis tom returneres den tilbagevrende tekst. Det tredie parameter definerer hvilke karakterer der skal fjes til outputtet nr en substring (understreng) returneres (Default: ...) .';
-$strTransformation_text_plain__unformatted = 'Viser HTML-kode som HTML-enheder. Der vises ingen HTML-formattering.';
+$strTransformation_text_plain__substr = 'Viser en del af en streng. Frste parameter er antal tegn der skal springes over fra begyndelsen af en streng (Standard 0). Andet parameter er antal tegn der returneres (Standard indtil enden af strengen). Det tredie parameter definerer hvilke karakterer der skal fjes til foran eller efter outputtet nr en substring (understreng) returneres (Standard: "...") .';
 $strTruncateQueries = 'Trunkr viste foresprgsler';
 $strTurkish = 'Tyrkisk';
 $strType = 'Datatype';
@@ -679,6 +771,7 @@ $strUpgrade = 'Du burde opdatere til %s %s eller senere.';
 $strUsage = 'Benyttelse';
 $strUseBackquotes = 'Brug \'backquotes\' p tabellers og felters navne';
 $strUseHostTable = 'Brug Host Tabel';
+$strUseTabKey = 'Brug TAB tasten for at flytte dig fra vrdi til vrdi, eller CTRL+piletasterne til at flytte frit omkring';
 $strUseTables = 'Benyt tabeller';
 $strUseTextField = 'Brug tekstfelt';
 $strUseThisValue = 'Brug denne vrdi';
@@ -695,9 +788,12 @@ $strValidateSQL = 'Validr SQL';
 $strValidatorError = 'SQL-validatoren kunne ikke initialiseres. Check venligst at du har de ndvendige php-udvidelser installeret som beskrevet i %sdokumentationen%s.';
 $strValue = 'Vrdi';
 $strVar = 'Variabel';
+$strVersionInformation = 'Versionsinformation';
+$strView = 'Visning';
 $strViewDump = 'Vis dump (skema) over tabel';
 $strViewDumpDB = 'Vis dump (skema) af database';
 $strViewDumpDatabases = 'Vis dump (skema) for databaser';
+$strViewHasBeenDropped = 'Visning %s er blevet droppet';
 
 $strWebServerUploadDirectory = 'web-server upload mappe';
 $strWebServerUploadDirectoryError = 'Mappen du har sat til upload-arbejde kan ikke findes';
@@ -706,6 +802,7 @@ $strWestEuropean = 'Vesteuropisk';
 $strWildcard = 'jokertegn';
 $strWindowNotFound = 'Det angivne browservindue kunne ikke opdateres. Mske har du lukket det overliggende vindue eller din browser blokerer for tvr-vindue opdateringer i sikkerhedsindstillingerne';
 $strWithChecked = 'Med det markerede:';
+$strWriteRequests = 'Write-foresprgsler';
 $strWritingCommentNotPossible = 'Skrivning af kommentar ikke muligt';
 $strWritingRelationNotPossible = 'Skrivning af relation ikke muligt';
 $strWrongUser = 'Forkert brugernavn/kodeord. Adgang ngtet.';
@@ -715,6 +812,6 @@ $strXML = 'XML';
 $strYes = 'Ja';
 
 $strZeroRemovesTheLimit = 'Bemrk: Indstilling af disse vrdier til 0 (nul) fjerner begrnsningen.';
-$strZip = '"zipped"';
+$strZip = '"zippet"';
 
 ?>
