@@ -1,16 +1,15 @@
 <?php
-/* $Id: latvian-windows-1257.inc.php,v 2.39 2004/09/21 11:00:41 rabus Exp $ */
+/* $Id: latvian-windows-1257.inc.php,v 2.80 2005/07/29 17:03:18 lem9 Exp $ */
 
 /**
  * Latvian language file by Sandis Jrics <sandisj at parks.lv>
  */
 
 $charset = 'windows-1257';
-$allow_recoding = TRUE;
 $text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
 $left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
 $right_font_family = 'arial, helvetica, geneva, sans-serif';
-$number_thousands_separator = ',';
+$number_thousands_separator = ' ';
 $number_decimal_separator = '.';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
 $byteUnits = array('baiti', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
@@ -34,6 +33,7 @@ $strAddConstraints = 'Pievienot ierobeojumus';
 $strAddDeleteColumn = 'Pievienot/Dzst laukus (kolonnas)';
 $strAddDeleteRow = 'Pievienot/Dzst ierakstu';
 $strAddDropDatabase = 'Pievienot DROP DATABASE';
+$strAddFields = 'Pievienot %s lauku(s)';
 $strAddHeaderComment = 'Ievietot virsrakst komentru (\\n atdala rindas)';
 $strAddIfNotExists = 'Pievienot IF NOT EXISTS';
 $strAddIntoComments = 'Pievienot komentros';
@@ -61,6 +61,7 @@ $strAnd = 'Un';
 $strAny = 'Jebkur';
 $strAnyHost = 'Jebkur hosts';
 $strAnyUser = 'Jebkur lietotjs';
+$strApproximateCount = 'Var bt aptuvens skaits. Skatt FAQ 3.11';
 $strArabic = 'Arbu';
 $strArmenian = 'Armu';
 $strAscending = 'Augo secb';
@@ -74,8 +75,15 @@ $strBack = 'Atpaka';
 $strBaltic = 'Baltijas';
 $strBeginCut = 'IZGRIEZT NO S VIETAS';
 $strBeginRaw = 'RINDAS SKUMS';
+$strBinLogEventType = 'Notikuma tips';
+$strBinLogInfo = 'Informcija';
+$strBinLogName = 'Log-faila nosaukums';
+$strBinLogOriginalPosition = 'Oriinl pozcija';
+$strBinLogPosition = 'Pozcija';
+$strBinLogServerId = 'Servera ID';
 $strBinary = 'Binrais';
 $strBinaryDoNotEdit = 'Binrais - netiek labots';
+$strBinaryLog = 'Binrais log-fails';
 $strBookmarkAllUsers = 'Dot ikvienam lietotjam pieeju ai grmatzmei';
 $strBookmarkDeleted = 'Ieraksts tika dzsts.';
 $strBookmarkLabel = 'Nosaukums';
@@ -115,7 +123,7 @@ $strCharsetOfFile = 'Tabulas kodjums:';
 $strCharsets = 'Rakstzmju kodjumi';
 $strCharsetsAndCollations = 'Rakstzmju kodjumi un izkrtojumi';
 $strCheckAll = 'Iezmt visu';
-$strCheckOverhead = 'Prbaudt prpildtos';
+$strCheckOverhead = 'Iezmt tabulas ar prtriu';
 $strCheckPrivs = 'Prbaudt privilijas';
 $strCheckPrivsLong = 'Prbaudt privilijas uz datubzi &quot;%s&quot;.';
 $strCheckTable = 'Prbaudt tabulu';
@@ -127,6 +135,7 @@ $strColumnPrivileges = 'Kolonnu specifisks privilijas';
 $strCommand = 'Komanda';
 $strComments = 'Komentri';
 $strCommentsForTable = 'KOMENTRI TABULAI';
+$strCompatibleHashing = 'MySQL&nbsp;4.0 savietojams';
 $strCompleteInserts = 'Pilnas INSERT izteiksmes';
 $strCompression = 'Kompresija';
 $strConfigFileError = 'phpMyAdmin nevar nolast konfigurcijas failu!<br />Tas var notikt, ja PHP atrod taj kdu, vai ar nevar atrast so failu.<br />Mginiet izsaukt konfigurcijas failu tiei, klikkinot linku zemk un lasiet PHP pazinojumu par kdm. Vairkum gadjumu kaut kur pietrukst pdia vai semikols.<br />Ja redzat tuku lapu, viss ir krtb.';
@@ -136,6 +145,7 @@ $strConnections = 'Konekcijas';
 $strConstraintsForDumped = 'Ierobeojumi izmestm tabulm';
 $strConstraintsForTable = 'Ierobeojumi tabulai';
 $strCookiesRequired = '"Cookies" ir jbt atautiem aiz  punkta.';
+$strCopyDatabaseOK = 'Datubze %s tika prkopta uz %s';
 $strCopyTable = 'Kopt tabulu uz (datubze<b>.</b>tabula):';
 $strCopyTableOK = 'Tabula %s tika prkopta uz %s.';
 $strCopyTableSameNames = 'Nevar nokopt tabulu uz viu pau!';
@@ -155,6 +165,7 @@ $strCzech = 'ehu';
 $strCzechSlovak = 'ehu-Slovku';
 
 $strDBComment = 'Datubzes komentrs: ';
+$strDBCopy = 'Kopt datubzi uz';
 $strDBGContext = 'Konteksts';
 $strDBGContextID = 'Konteksta ID';
 $strDBGHits = 'Apmekljumi';
@@ -227,6 +238,7 @@ $strEndRaw = 'RINDAS BEIGAS';
 $strEnglish = 'Angu';
 $strEnglishPrivileges = ' Piezme: MySQL priviliju apzmjumi tiek rakstti angu valod ';
 $strError = 'Kda';
+$strEscapeWildcards = 'Aizstjjzmes _ un % jaizsarg ar \ priek, lai izmantotu ts burtiski';
 $strEstonian = 'Igauu';
 $strExcelEdition = 'Excel redakcija';
 $strExcelOptions = 'Excel opcijas';
@@ -296,11 +308,16 @@ $strIndex = 'Indekss';
 $strIndexHasBeenDropped = 'Indekss %s tika izdzsts';
 $strIndexName = 'Indeksa nosaukums&nbsp;:';
 $strIndexType = 'Indeksa tips&nbsp;:';
+$strIndexWarningMultiple = 'Vairk k viena %s atslga tika izveidota kolonnai `%s`';
+$strIndexWarningPrimary = 'PRIMARY un INDEX atslgas nevar abas reiz tikt uzliktas kolonnai `%s`';
+$strIndexWarningTable = 'Problmas ar indeksiem tabul `%s`';
+$strIndexWarningUnique = 'UNIQUE un INDEX atslgas nevar abas reiz tikt uzliktas kolonnai `%s`';
 $strIndexes = 'Indeksi';
 $strInnodbStat = 'InnoDB statuss';
 $strInsecureMySQL = 'Jsu konfigurcijas fails satur iestdjumus (lietotjs "root" bez paroles), kas atbilst noklustajam MySQL privilitajam lietotjam. Jsu MySQL serveris strd ar o noklusto variantu, ir atvrts uzbrukumiem, un Jums tiem jaiztaisa is drobas caurums.';
 $strInsert = 'Pievienot';
 $strInsertAsNewRow = 'Ievietot k jaunu rindu';
+$strInsertBookmarkTitle = 'Ldzu ierakstiet grmatzmes virsrakstu';
 $strInsertNewRow = 'Pievienot jaunu rindu';
 $strInsertTextfiles = 'Ievietot tabul datus no teksta faila';
 $strInsertedRowId = 'Ievietots rindas id:';
@@ -382,6 +399,7 @@ $strName = 'Nosaukums';
 $strNeedPrimaryKey = 'Nodefinjiet primro atslgu ai tabulai.';
 $strNext = 'Nkamie';
 $strNo = 'N';
+$strNoActivity = 'Nebija aktivittes vairk k %s sekunu laik, ldzu autorizjieties vlreiz';
 $strNoDatabases = 'Nav datubzu';
 $strNoDatabasesSelected = 'Datubze nav izvlta.';
 $strNoDescription = 'Bez apraksta';
@@ -401,13 +419,13 @@ $strNoRights = 'Jums nav pietiekoi tiesbu, lai atrastos eit tagad!';
 $strNoRowsSelected = 'Rindas nav iezmtas';
 $strNoSpace = 'Nepietiek vietas, lai saglabtu failu %s.';
 $strNoTablesFound = 'Tabulas nav atrastas aj datubz.';
+$strNoThemeSupport = 'Nav tmu atbalsta, ldzu prbaudiet jsu konfigurciju un/vai Jsu tmas direktorij %s.';
 $strNoUsersFound = 'Lietotji netika atrasti.';
 $strNoValidateSQL = 'Neprbaudt SQL';
 $strNone = 'Nav';
 $strNotNumber = 'Tas nav numurs!';
 $strNotOK = 'nav OK';
 $strNotSet = 'Tabula <b>%s</b> nav atrasta vai nav atzmeta iek %s';
-$strNotValidNumber = ' nav dergs lauku skaits!';
 $strNull = 'Nulle';
 $strNumSearchResultsInTable = '%s rezultti tabul <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Kopum:</b> <i>%s</i> rezultti';
@@ -432,6 +450,7 @@ $strPartialText = 'Daji teksti';
 $strPassword = 'Parole';
 $strPasswordChanged = 'Lietotja %s parole tika veiksmgi mainta.';
 $strPasswordEmpty = 'Parole nav nordta!';
+$strPasswordHashing = 'Paroles jaukana';
 $strPasswordNotSame = 'Paroles nesakrt!';
 $strPdfDbSchema = 'Datubzes "%s" shma, %s. lapa';
 $strPdfInvalidTblName = 'Tabula "%s" neeksist!';
@@ -439,6 +458,7 @@ $strPdfNoTables = 'Nav tabulu';
 $strPerHour = 'stund';
 $strPerMinute = 'mint';
 $strPerSecond = 'sekund';
+$strPersian = 'Persieu';
 $strPhoneBook = 'telefonu grmata';
 $strPhp = 'Izveidot PHP kodu';
 $strPmaDocumentation = 'phpMyAdmin dokumentcija';
@@ -486,7 +506,6 @@ $strPrivDescUsage = 'Nav priviliju.';
 $strPrivileges = 'Privilijas';
 $strPrivilegesReloaded = 'Privilijas tika veiksmgi prldtas.';
 $strProcesslist = 'Procesu saraksts';
-$strProperties = 'pabas';
 $strPutColNames = 'Likt kolonnu nosaukumus pirmaj rind';
 
 $strQBE = 'Vaicjums pc parauga';
@@ -504,7 +523,7 @@ $strReType = 'Atkrtojiet';
 $strReceived = 'Saemts';
 $strRecords = 'Ieraksti';
 $strReferentialIntegrity = 'Prbaudt referencilo integritti:';
-$strRefresh = 'Atkaunot';
+$strRefresh = 'Atjaunot';
 $strRelationNotWorking = 'Papildiespjas darbam ar saisttm tabulm tika izslgtas. Lai uzzintu kpc, klikkiniet %seit%s.';
 $strRelationView = 'Relciju prskats';
 $strRelationalSchema = 'Relciju shma';
@@ -568,6 +587,7 @@ $strSearchType = 'Atrast:';
 $strSecretRequired = 'Konfigurcijas fails tagad prasa slepeno paroli (blowfish_secret).';
 $strSelectADb = 'Ldzu izvlieties datubzi';
 $strSelectAll = 'Iezmt visu';
+$strSelectBinaryLog = 'Izvlieties binro log-failu apskatei';
 $strSelectFields = 'Izvlieties laukus (kaut vienu):';
 $strSelectNumRows = 'vaicjum';
 $strSelectTables = 'Izvlieties tabulas';
@@ -623,6 +643,7 @@ $strSubmit = 'Nostt';
 $strSuccess = 'Jsu SQL vaicjums tika veiksmgi izpildts';
 $strSum = 'Kopum';
 $strSwedish = 'Zviedru';
+$strSwitchToDatabase = 'Prslgties uz nokopto datubzi';
 $strSwitchToTable = 'Prslgties uz nokopto tabulu';
 
 $strTable = 'Tabula';
@@ -665,7 +686,6 @@ $strTransformation_text_plain__formatted = 'Saglab lauka oriinlo formatjumu. Spe
 $strTransformation_text_plain__imagelink = 'Parda attlu un linku, lauks satur faila nosauumu; pirm opcija ir prefikss, piemram, "http://domens.lv/", otr opcija ir platums pikseos, tre ir augstums.';
 $strTransformation_text_plain__link = 'Parda attlu un linku, lauks satur faila nosauumu; pirm opcija ir prefikss, piemram, "http://domens.lv/", otr opcija ir linka nosaukums.';
 $strTransformation_text_plain__substr = 'Parda tikai virknes dau. Pirm opcija ir nobde, kas nosaka, kur Jsu teksts skas (noklusjums 0). Otr opcija ir atgrieam teksta garums. Ja tuka, atgrie visu atlikuo tekstu. Tre opcija nosaka rakstzmes, kas tiks pievienotas apgriezts virknes gal (noklusjums: ...) .';
-$strTransformation_text_plain__unformatted = 'Parda HTML k HTML simbolus. HTML formatjums netiek rdts.';
 $strTruncateQueries = 'Ierobeot pardto vaicjumu garumu';
 $strTurkish = 'Turku';
 $strType = 'Tips';
@@ -684,6 +704,7 @@ $strUpgrade = 'Jums ir juzliek %s %s vai jaunks.';
 $strUsage = 'Aizem';
 $strUseBackquotes = 'Lietot apostrofa simbolu [`] tabulu un lauku nosaukumiem';
 $strUseHostTable = 'Lietot hostu tabulu';
+$strUseTabKey = 'Lietojiet TAB taustiu, lai prvietotos no vrtbas ldz vrtbai, vai CTRL+bultias, lai prvietotos jebkur viet';
 $strUseTables = 'Lietot tabulas';
 $strUseTextField = 'Lietot teksta lauku';
 $strUseThisValue = 'Lietot o vrtbu';
@@ -722,5 +743,82 @@ $strYes = 'J';
 $strZeroRemovesTheLimit = 'Piezme: o opciju uzstdana uz 0 (nulli) atce ierobeojumus.';
 $strZip = 'Arhivts ar zip';
 
-$strPersian = 'Persian';  //to translate
+// To translate:
+$strAfterInsertNext = 'Edit next row';  //to translate
+
+$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
+$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
+
+$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
+
+$strView = 'View';  //to translate
+$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
+$strEngines = 'Engines';  //to translate
+$strStorageEngines = 'Storage Engines';  //to translate
+$strStorageEngine = 'Storage Engine';  //to translate
+$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
+$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
+$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
+$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
+$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
+$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
+$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
+$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
+$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
+$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
+$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
+$strMyISAMRepairThreads = 'Repair threads';  //to translate
+$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
+$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
+$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
+$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
+$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
+$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
+$strVersionInformation = 'Version information';  //to translate
+$strInnoDBDataHomeDir = 'Data home directory';  //to translate
+$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
+$strInnoDBDataFilePath = 'Data files';  //to translate
+$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
+$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
+$strBufferPool = 'Buffer Pool';  //to translate
+$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
+$strDataPages = 'Pages containing data';  //to translate
+$strFreePages = 'Free pages';  //to translate
+$strBusyPages = 'Busy pages';  //to translate
+$strDirtyPages = 'Dirty pages';  //to translate
+$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
+$strLatchedPages = 'Latched pages';  //to translate
+$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
+$strReadRequests = 'Read requests';  //to translate
+$strWriteRequests = 'Write requests';  //to translate
+$strBufferReadMisses = 'Read misses';  //to translate
+$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
+$strBufferWriteWaits = 'Write waits';  //to translate
+$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
+$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
+$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
+$strHTMLWord = 'Microsoft Word 2000';  //to translate
+$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
+$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
+$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
+$strInnoDBPages = 'pages';  //to translate
+$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
+$strPrivDescCreateView = 'Allows creating new views.';  //to translate
+$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
+$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
+$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
+$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
+$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
+$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
+$strGeneratePassword = 'Generate Password';  //to translate
+$strGenerate = 'Generate';  //to translate
+$strCopy = 'Copy';  //to translate
+$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
+$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
+$strInvalidRowNumber = '%d is not valid row number.';  //to translate
+$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
+$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
+$strAndThen = 'and then';  //to translate
 ?>
