@@ -1,5 +1,5 @@
 <?php
-/* $Id: display_export.lib.php,v 2.22 2004/09/16 10:59:26 garvinhicking Exp $ */
+/* $Id: display_export.lib.php,v 2.32 2005/08/22 21:41:20 nijel Exp $ */
 // vim: expandtab sw=4 ts=4 sts=4:
 
 // Get relations & co. status
@@ -63,6 +63,8 @@ if (isset($sql_query)) {
         getElement("csv_options").style.display = 'none';
         getElement("excel_options").style.display = 'none';
         getElement("latex_options").style.display = 'none';
+        getElement("htmlexcel_options").style.display = 'none';
+        getElement("htmlword_options").style.display = 'none';
 <?php if ($xls) { ?>
         getElement("xls_options").style.display = 'none';
 <?php } ?>
@@ -76,6 +78,10 @@ if (isset($sql_query)) {
         hide_them_all();
         if (getElement('radio_dump_latex').checked) {
             getElement('latex_options').style.display = 'block';
+        } else if (getElement('radio_dump_htmlexcel').checked) {
+            getElement('htmlexcel_options').style.display = 'block';
+        } else if (getElement('radio_dump_htmlword').checked) {
+            getElement('htmlword_options').style.display = 'block';
 <?php if ($xls) { ?>
         } else if (getElement('radio_dump_xls').checked) {
             getElement('xls_options').style.display = 'block';
@@ -137,6 +143,16 @@ if (isset($sql_query)) {
                 </td></tr>
 
 
+            <!-- HTML Excel -->
+                <tr><td bgcolor="<?php echo $cfg['BgcolorOne']; ?>">
+                    <input type="radio" name="what" value="htmlexcel" id="radio_dump_htmlexcel"  onclick="if (this.checked) { hide_them_all(); getElement('htmlexcel_options').style.display = 'block'; getElement('checkbox_dump_asfile').checked = true;};  return true" <?php PMA_exportIsActive('format', 'htmlexcel'); ?> /><label for="radio_dump_htmlexcel"><?php echo $strHTMLExcel; ?></label>
+               </td></tr>
+
+            <!-- HTML Word -->
+                <tr><td bgcolor="<?php echo $cfg['BgcolorOne']; ?>">
+                    <input type="radio" name="what" value="htmlword" id="radio_dump_htmlword"  onclick="if (this.checked) { hide_them_all(); getElement('htmlword_options').style.display = 'block'; getElement('checkbox_dump_asfile').checked = true;};  return true" <?php PMA_exportIsActive('format', 'htmlword'); ?> /><label for="radio_dump_htmlword"><?php echo $strHTMLWord; ?></label>
+               </td></tr>
+
 <?php if ($xls) { ?>
             <!-- Native Excel -->
                 <tr><td bgcolor="<?php echo $cfg['BgcolorOne']; ?>">
@@ -186,11 +202,9 @@ if (isset($sql_query)) {
                 <tr>
                     <td bgcolor="<?php echo $cfg['BgcolorOne']; ?>">
                         <?php echo $strAddHeaderComment; ?>: <input type="text" name="header_comment" value="<?php echo $cfg['Export']['sql_header_comment']; ?>" class="textfield" size="30" style="vertical-align: middle" /><br />
-                        <input type="checkbox" name="use_transaction" value="yes" id="checkbox_use_transaction" <?php PMA_exportCheckboxCheck('sql_use_transaction'); ?> style="vertical-align: middle" />
-                        <label for="checkbox_use_transaction"><?php echo $strEncloseInTransaction; ?></label><br />
+                        <input type="checkbox" name="use_transaction" value="yes" id="checkbox_use_transaction" <?php PMA_exportCheckboxCheck('sql_use_transaction'); ?> style="vertical-align: middle" /><label for="checkbox_use_transaction"><?php echo $strEncloseInTransaction; ?></label><br />
 
-                        <input type="checkbox" name="disable_fk" value="yes" id="checkbox_disable_fk" <?php PMA_exportCheckboxCheck('sql_disable_fk'); ?> style="vertical-align: middle" />
-  	                    <label for="checkbox_disable_fk"><?php echo $strDisableForeignChecks; ?></label><br />
+                        <input type="checkbox" name="disable_fk" value="yes" id="checkbox_disable_fk" <?php PMA_exportCheckboxCheck('sql_disable_fk'); ?> style="vertical-align: middle" /><label for="checkbox_disable_fk"><?php echo $strDisableForeignChecks; ?></label><br />
                     </td>
                 </tr>
 <?php
@@ -200,8 +214,7 @@ if ($export_type == 'server') {
                 <tr>
                     <td bgcolor="<?php echo $cfg['BgcolorOne']; ?>">
                         <b><?php echo $strDatabaseExportOptions; ?>:</b><br />
-                        <input type="checkbox" name="drop_database" value="yes" id="checkbox_drop_database" <?php PMA_exportCheckboxCheck('sql_drop_database'); ?> style="vertical-align: middle" />
-                        <label for="checkbox_drop_database"><?php echo $strAddDropDatabase; ?></label>
+                        <input type="checkbox" name="drop_database" value="yes" id="checkbox_drop_database" <?php PMA_exportCheckboxCheck('sql_drop_database'); ?> style="vertical-align: middle" /><label for="checkbox_drop_database"><?php echo $strAddDropDatabase; ?></label>
                     </td>
                 </tr>
 
@@ -211,45 +224,61 @@ if (!$hide_structure) { ?>
                 <!-- For structure -->
                 <tr>
                     <td bgcolor="<?php echo $cfg['BgcolorOne']; ?>">
-                        <input type="checkbox" name="sql_structure" value="structure" id="checkbox_sql_structure" <?php PMA_exportCheckboxCheck('sql_structure'); ?> onclick="if (!this.checked &amp;&amp; !getElement('checkbox_sql_data').checked) return false; else return true;" />
-                        <label for="checkbox_sql_structure"><b><?php echo $strStructure; ?>:</b></label><br />
+                        <input type="checkbox" name="sql_structure" value="structure" id="checkbox_sql_structure" <?php PMA_exportCheckboxCheck('sql_structure'); ?> onclick="if (!this.checked &amp;&amp; !getElement('checkbox_sql_data').checked) return false; else return true;" /><label for="checkbox_sql_structure"><b><?php echo $strStructure; ?>:</b></label><br />
 
-                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="drop" value="1" id="checkbox_dump_drop" <?php PMA_exportCheckboxCheck('sql_drop_table'); ?> style="vertical-align: middle" />
-                        <label for="checkbox_dump_drop"><?php echo $strStrucDrop; ?></label><br />
+                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="drop" value="1" id="checkbox_dump_drop" <?php PMA_exportCheckboxCheck('sql_drop_table'); ?> style="vertical-align: middle" /><label for="checkbox_dump_drop"><?php echo $strStrucDrop; ?></label><br />
 
-                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="if_not_exists" value="1" id="checkbox_dump_if_not_exists" <?php PMA_exportCheckboxCheck('sql_if_not_exists'); ?> style="vertical-align: middle" />
-                        <label for="checkbox_dump_if_not_exists"><?php echo $strAddIfNotExists; ?></label><br />
+                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="if_not_exists" value="1" id="checkbox_dump_if_not_exists" <?php PMA_exportCheckboxCheck('sql_if_not_exists'); ?> style="vertical-align: middle" /><label for="checkbox_dump_if_not_exists"><?php echo $strAddIfNotExists; ?></label><br />
 
-                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="auto_increment" value="1" id="checkbox_auto_increment" <?php PMA_exportCheckboxCheck('sql_auto_increment'); ?> style="vertical-align: middle" />
-                        <label for="checkbox_auto_increment"><?php echo $strAddAutoIncrement; ?></label><br />
+                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="auto_increment" value="1" id="checkbox_auto_increment" <?php PMA_exportCheckboxCheck('sql_auto_increment'); ?> style="vertical-align: middle" /><label for="checkbox_auto_increment"><?php echo $strAddAutoIncrement; ?></label><br />
 
-                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="use_backquotes" value="1" id="checkbox_dump_use_backquotes" <?php PMA_exportCheckboxCheck('sql_backquotes'); ?> style="vertical-align: middle" />
-                        <label for="checkbox_dump_use_backquotes"><?php echo $strUseBackquotes; ?></label><br />
+                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="use_backquotes" value="1" id="checkbox_dump_use_backquotes" <?php PMA_exportCheckboxCheck('sql_backquotes'); ?> style="vertical-align: middle" /><label for="checkbox_dump_use_backquotes"><?php echo $strUseBackquotes; ?></label><br />
 
                         &nbsp;&nbsp;&nbsp;&nbsp;<b><?php echo $strAddIntoComments; ?></b><br />
 
-                        &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="sql_dates" value="yes" id="checkbox_sql_dates" <?php PMA_exportCheckboxCheck('sql_dates'); ?> style="vertical-align: middle" />
-                        <label for="checkbox_sql_dates"><?php echo $strCreationDates; ?></label><br />
+                        &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="sql_dates" value="yes" id="checkbox_sql_dates" <?php PMA_exportCheckboxCheck('sql_dates'); ?> style="vertical-align: middle" /><label for="checkbox_sql_dates"><?php echo $strCreationDates; ?></label><br />
 <?php
     if (!empty($cfgRelation['relation'])) {
 ?>
-                        &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="sql_relation" value="yes" id="checkbox_sql_use_relation" <?php PMA_exportCheckboxCheck('sql_relation'); ?> style="vertical-align: middle" />
-                        <label for="checkbox_sql_use_relation"><?php echo $strRelations; ?></label><br />
+                        &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="sql_relation" value="yes" id="checkbox_sql_use_relation" <?php PMA_exportCheckboxCheck('sql_relation'); ?> style="vertical-align: middle" /><label for="checkbox_sql_use_relation"><?php echo $strRelations; ?></label><br />
 <?php
     } // end relation
-    if (!empty($cfgRelation['commwork'])) {
+    if (!empty($cfgRelation['commwork']) && PMA_MYSQL_INT_VERSION < 40100) {
 ?>
-                        &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="sql_comments" value="yes" id="checkbox_sql_use_comments" <?php PMA_exportCheckboxCheck('sql_comments'); ?> style="vertical-align: middle" />
-                        <label for="checkbox_sql_use_comments"><?php echo $strComments; ?></label><br />
+                        &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="sql_comments" value="yes" id="checkbox_sql_use_comments" <?php PMA_exportCheckboxCheck('sql_comments'); ?> style="vertical-align: middle" /><label for="checkbox_sql_use_comments"><?php echo $strComments; ?></label><br />
 <?php
     } // end comments
     if ($cfgRelation['mimework']) {
 ?>
-                        &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="sql_mime" value="yes" id="checkbox_sql_use_mime" <?php PMA_exportCheckboxCheck('sql_mime'); ?> style="vertical-align: middle" />
-                        <label for="checkbox_sql_use_mime"><?php echo $strMIME_MIMEtype; ?></label><br />
+                        &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="sql_mime" value="yes" id="checkbox_sql_use_mime" <?php PMA_exportCheckboxCheck('sql_mime'); ?> style="vertical-align: middle" /><label for="checkbox_sql_use_mime"><?php echo $strMIME_MIMEtype; ?></label><br />
 <?php
     } // end MIME
+    if (PMA_MYSQL_INT_VERSION >= 40100) {
 ?>
+                        <label for="select_sql_compat"><?php echo $strSQLExportCompatibility; ?>:&nbsp;</label><select name="sql_compat" id="select_sql_compat" style="vertical-align: middle">
+                        <?php
+                        $compats = array('NONE');
+                        if (PMA_MYSQL_INT_VERSION >= 40101) {
+                            $compats[] = 'ANSI';
+                            $compats[] = 'DB2';
+                            $compats[] = 'MAXDB';
+                            $compats[] = 'MYSQL323';
+                            $compats[] = 'MYSQL40';
+                            $compats[] = 'MSSQL';
+                            $compats[] = 'ORACLE';
+                            $compats[] = 'POSTGRESQL';
+                            if (PMA_MYSQL_INT_VERSION >= 50001) {
+                                $compats[] = 'TRADITIONAL';
+                            }
+                        }
+                        foreach ($compats as $x) {
+                            echo '<option value="' . $x . '"' . ($cfg['Export']['sql_compat'] == $x ? ' selected="selected"' : '' ) . '>' . $x . '</option>' . "\n";
+                        }
+                        ?>
+                        </select>
+                        <?php echo PMA_showMySQLDocu('manual_MySQL_Database_Administration', 'Server_SQL_mode') . "\n";
+    }
+    ?>
                     </td>
                 </tr>
 <?php
@@ -259,26 +288,19 @@ if (!$hide_structure) { ?>
                 <!-- For data -->
                 <tr>
                     <td bgcolor="<?php echo $cfg['BgcolorOne']; ?>">
-                        <input type="checkbox" name="sql_data" value="data" id="checkbox_sql_data" <?php PMA_exportCheckboxCheck('sql_data'); ?> onclick="if (!this.checked &amp;&amp; (!getElement('checkbox_sql_structure') || !getElement('checkbox_sql_structure').checked)) return false; else return true;" style="vertical-align: middle" />
-                        <label for="checkbox_sql_data"><b><?php echo $strData; ?>:</b></label><br />
+                        <input type="checkbox" name="sql_data" value="data" id="checkbox_sql_data" <?php PMA_exportCheckboxCheck('sql_data'); ?> onclick="if (!this.checked &amp;&amp; (!getElement('checkbox_sql_structure') || !getElement('checkbox_sql_structure').checked)) return false; else return true;" style="vertical-align: middle" /><label for="checkbox_sql_data"><b><?php echo $strData; ?>:</b></label><br />
 
-                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="showcolumns" value="yes" id="checkbox_dump_showcolumns" <?php PMA_exportCheckboxCheck('sql_columns'); ?> style="vertical-align: middle" />
-                        <label for="checkbox_dump_showcolumns"><?php echo $strCompleteInserts; ?></label><br />
+                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="showcolumns" value="yes" id="checkbox_dump_showcolumns" <?php PMA_exportCheckboxCheck('sql_columns'); ?> style="vertical-align: middle" /><label for="checkbox_dump_showcolumns"><?php echo $strCompleteInserts; ?></label><br />
 
-                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="extended_ins" value="yes" id="checkbox_dump_extended_ins" <?php PMA_exportCheckboxCheck('sql_extended'); ?> style="vertical-align: middle" />
-                        <label for="checkbox_dump_extended_ins"><?php echo $strExtendedInserts; ?></label><br />
+                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="extended_ins" value="yes" id="checkbox_dump_extended_ins" <?php PMA_exportCheckboxCheck('sql_extended'); ?> style="vertical-align: middle" /><label for="checkbox_dump_extended_ins"><?php echo $strExtendedInserts; ?></label><br />
 
-                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="delayed" value="yes" id="checkbox_dump_delayed" <?php PMA_exportCheckboxCheck('sql_delayed'); ?> style="vertical-align: middle" />
-                        <label for="checkbox_dump_delayed"><?php echo $strDelayedInserts; ?></label><br />
+                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="delayed" value="yes" id="checkbox_dump_delayed" <?php PMA_exportCheckboxCheck('sql_delayed'); ?> style="vertical-align: middle" /><label for="checkbox_dump_delayed"><?php echo $strDelayedInserts; ?></label><br />
 
-                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="sql_ignore" value="yes" id="checkbox_dump_ignore" <?php PMA_exportCheckboxCheck('sql_ignore'); ?> style="vertical-align: middle" />
-                        <label for="checkbox_dump_ignore"><?php echo $strIgnoreInserts; ?></label><br />
+                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="sql_ignore" value="yes" id="checkbox_dump_ignore" <?php PMA_exportCheckboxCheck('sql_ignore'); ?> style="vertical-align: middle" /><label for="checkbox_dump_ignore"><?php echo $strIgnoreInserts; ?></label><br />
 
-                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="hexforbinary" value="yes" id="checkbox_hexforbinary" <?php PMA_exportCheckboxCheck('sql_hex_for_binary'); ?> style="vertical-align: middle" />
-                        <label for="checkbox_hexforbinary"><?php echo $strHexForBinary; ?></label><br />
+                        &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="hexforbinary" value="yes" id="checkbox_hexforbinary" <?php PMA_exportCheckboxCheck('sql_hex_for_binary'); ?> style="vertical-align: middle" /><label for="checkbox_hexforbinary"><?php echo $strHexForBinary; ?></label><br />
 
-                        <label for="select_sql_type"><?php echo $strSQLExportType; ?>:&nbsp;</label>
-                        <select name="sql_type" id="select_sql_type" style="vertical-align: middle">
+                        <label for="select_sql_type"><?php echo $strSQLExportType; ?>:&nbsp;</label><select name="sql_type" id="select_sql_type" style="vertical-align: middle">
                             <option value="insert"<?php echo $cfg['Export']['sql_type'] == 'insert' ? ' selected="selected"' : ''; ?>>INSERT</option>
                             <option value="update"<?php echo $cfg['Export']['sql_type'] == 'update' ? ' selected="selected"' : ''; ?>>UPDATE</option>
                             <option value="replace"<?php echo $cfg['Export']['sql_type'] == 'replace' ? ' selected="selected"' : ''; ?>>REPLACE</option>
@@ -297,8 +319,7 @@ if (!$hide_structure) { ?>
                 <tr><th align="left"><?php echo $strLaTeXOptions; ?></th></tr>
                 <tr>
                     <td bgcolor="<?php echo $cfg['BgcolorOne']; ?>">
-                        <input type="checkbox" name="latex_caption" value="yes" id="checkbox_latex_show_caption" <?php PMA_exportCheckboxCheck('latex_caption'); ?> style="vertical-align: middle" />
-                        <label for="checkbox_latex_show_caption"><?php echo $strLatexIncludeCaption; ?></label><br />
+                        <input type="checkbox" name="latex_caption" value="yes" id="checkbox_latex_show_caption" <?php PMA_exportCheckboxCheck('latex_caption'); ?> style="vertical-align: middle" /><label for="checkbox_latex_show_caption"><?php echo $strLatexIncludeCaption; ?></label><br />
                     </td>
                 </tr>
 
@@ -306,8 +327,7 @@ if (!$hide_structure) { ?>
                 <!-- For structure -->
                 <tr>
                     <td bgcolor="<?php echo $cfg['BgcolorOne']; ?>">
-                    <input type="checkbox" name="latex_structure" value="structure" id="checkbox_latex_structure" <?php PMA_exportCheckboxCheck('latex_structure'); ?> onclick="if (!this.checked &amp;&amp; !getElement('checkbox_latex_data').checked) return false; else return true;" style="vertical-align: middle" />
-                    <label for="checkbox_latex_structure"><b><?php echo $strStructure; ?></b></label><br />
+                    <input type="checkbox" name="latex_structure" value="structure" id="checkbox_latex_structure" <?php PMA_exportCheckboxCheck('latex_structure'); ?> onclick="if (!this.checked &amp;&amp; !getElement('checkbox_latex_data').checked) return false; else return true;" style="vertical-align: middle" /><label for="checkbox_latex_structure"><b><?php echo $strStructure; ?></b></label><br />
                     <table border="0" cellspacing="1" cellpadding="0">
                         <tr>
                             <td>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td>
@@ -334,20 +354,17 @@ if (!$hide_structure) { ?>
 <?php
     if (!empty($cfgRelation['relation'])) {
 ?>
-                    &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="latex_relation" value="yes" id="checkbox_latex_use_relation" <?php PMA_exportCheckboxCheck('latex_relation'); ?> style="vertical-align: middle" />
-                    <label for="checkbox_latex_use_relation"><?php echo $strRelations; ?></label><br />
+                    &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="latex_relation" value="yes" id="checkbox_latex_use_relation" <?php PMA_exportCheckboxCheck('latex_relation'); ?> style="vertical-align: middle" /><label for="checkbox_latex_use_relation"><?php echo $strRelations; ?></label><br />
 <?php
     } // end relation
     if ($cfgRelation['commwork']) {
 ?>
-                    &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="latex_comments" value="yes" id="checkbox_latex_use_comments" <?php PMA_exportCheckboxCheck('latex_comments'); ?> style="vertical-align: middle" />
-                    <label for="checkbox_latex_use_comments"><?php echo $strComments; ?></label><br />
+                    &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="latex_comments" value="yes" id="checkbox_latex_use_comments" <?php PMA_exportCheckboxCheck('latex_comments'); ?> style="vertical-align: middle" /><label for="checkbox_latex_use_comments"><?php echo $strComments; ?></label><br />
 <?php
     } // end comments
     if ($cfgRelation['mimework']) {
 ?>
-                    &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="latex_mime" value="yes" id="checkbox_latex_use_mime" <?php PMA_exportCheckboxCheck('latex_mime'); ?> style="vertical-align: middle" />
-                    <label for="checkbox_latex_use_mime"><?php echo $strMIME_MIMEtype; ?></label><br />
+                    &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="latex_mime" value="yes" id="checkbox_latex_use_mime" <?php PMA_exportCheckboxCheck('latex_mime'); ?> style="vertical-align: middle" /><label for="checkbox_latex_use_mime"><?php echo $strMIME_MIMEtype; ?></label><br />
 <?php
     } // end MIME
 ?>
@@ -359,10 +376,8 @@ if (!$hide_structure) { ?>
             <!-- For data -->
             <tr>
                 <td bgcolor="<?php echo $cfg['BgcolorOne']; ?>">
-                    <input type="checkbox" name="latex_data" value="data" id="checkbox_latex_data" <?php PMA_exportCheckboxCheck('latex_data'); ?> onclick="if (!this.checked &amp;&amp; (!getElement('checkbox_latex_structure') || !getElement('checkbox_latex_structure').checked)) return false; else return true;" style="vertical-align: middle" />
-                    <label for="checkbox_latex_data"><b><?php echo $strData; ?>:</b></label><br />
-                    &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="latex_showcolumns" value="yes" id="ch_latex_showcolumns" <?php PMA_exportCheckboxCheck('latex_columns'); ?> style="vertical-align: middle" />
-                    <label for="ch_latex_showcolumns"><?php echo $strColumnNames; ?></label><br />
+                    <input type="checkbox" name="latex_data" value="data" id="checkbox_latex_data" <?php PMA_exportCheckboxCheck('latex_data'); ?> onclick="if (!this.checked &amp;&amp; (!getElement('checkbox_latex_structure') || !getElement('checkbox_latex_structure').checked)) return false; else return true;" style="vertical-align: middle" /><label for="checkbox_latex_data"><b><?php echo $strData; ?>:</b></label><br />
+                    &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="latex_showcolumns" value="yes" id="ch_latex_showcolumns" <?php PMA_exportCheckboxCheck('latex_columns'); ?> style="vertical-align: middle" /><label for="ch_latex_showcolumns"><?php echo $strColumnNames; ?></label><br />
                     <table border="0" cellspacing="1" cellpadding="0">
                         <tr>
                             <td>&nbsp;&nbsp;&nbsp;&nbsp;</td>
@@ -448,8 +463,7 @@ if (!$hide_structure) { ?>
                         </td>
                     </tr>
                 </table>
-                <input type="checkbox" name="showcsvnames" value="yes" id="checkbox_dump_showcsvnames" <?php PMA_exportCheckboxCheck('csv_columns'); ?> style="vertical-align: middle" />
-                <label for="checkbox_dump_showcsvnames"><?php echo $strPutColNames; ?></label>
+                <input type="checkbox" name="showcsvnames" value="yes" id="checkbox_dump_showcsvnames" <?php PMA_exportCheckboxCheck('csv_columns'); ?> style="vertical-align: middle" /><label for="checkbox_dump_showcsvnames"><?php echo $strPutColNames; ?></label>
             </td>
         </tr>
         </table>
@@ -474,8 +488,7 @@ if (!$hide_structure) { ?>
                     </tr>
                     <tr>
                         <td colspan="2">
-                            <input type="checkbox" name="showexcelnames" value="yes" id="checkbox_dump_showexcelnames" <?php PMA_exportCheckboxCheck('excel_columns'); ?> style="vertical-align: middle" />
-                            <label for="checkbox_dump_showexcelnames"><?php echo $strPutColNames; ?></label>
+                            <input type="checkbox" name="showexcelnames" value="yes" id="checkbox_dump_showexcelnames" <?php PMA_exportCheckboxCheck('excel_columns'); ?> style="vertical-align: middle" /><label for="checkbox_dump_showexcelnames"><?php echo $strPutColNames; ?></label>
                         </td>
                     </tr>
                     <tr>
@@ -497,6 +510,69 @@ if (!$hide_structure) { ?>
             </div>
 
 
+            <!-- HTML Excel options -->
+            <div id="htmlexcel_options">
+                <table border="0" cellspacing="1" cellpadding="0" width="400">
+                    <tr>
+                        <th align="left">
+                           <b><?php echo $strHTMLExcelOptions; ?></b>
+                           <input type="hidden" name="htmlexcel_data" value="htmlexcel_data" />
+                        </th>
+                   </tr>
+                   <tr><td bgcolor="<?php echo $cfg['BgcolorOne']; ?>">
+                <table border="0" cellspacing="1" cellpadding="0">
+                       <tr>
+                           <td>
+                            <?php echo $strReplaceNULLBy; ?>&nbsp;
+                        </td>
+                        <td>
+                            <input type="text" name="htmlexcel_replace_null" size="20" value="<?php echo $cfg['Export']['htmlexcel_null']; ?>" class="textfield" />
+                        </td>
+                    </tr>
+                    <tr>
+                        <td>
+                            <input type="checkbox" name="htmlexcel_shownames" value="yes" id="checkbox_dump_htmlexcel_shownames" <?php PMA_exportCheckboxCheck('htmlexcel_columns'); ?> /><label for="checkbox_dump_htmlexcel_shownames"><?php echo $strPutColNames; ?></label>
+                        </td>
+                    </tr>
+                </table>
+                    </td></tr>
+               </table>
+            </div>
+
+
+            <!-- HTML Word options -->
+            <div id="htmlword_options">
+                <table border="0" cellspacing="1" cellpadding="0" width="400">
+                    <tr>
+                        <th align="left">
+                           <b><?php echo $strHTMLWordOptions; ?></b>
+                        </th>
+                   </tr>
+                   <tr><td bgcolor="<?php echo $cfg['BgcolorOne']; ?>">
+                    <input type="checkbox" name="htmlword_structure" value="structure" id="checkbox_htmlword_structure" <?php PMA_exportCheckboxCheck('htmlword_structure'); ?> onclick="if (!this.checked &amp;&amp; (!getElement('checkbox_htmlword_data') || !getElement('checkbox_htmlword_data').checked)) return false; else return true;" style="vertical-align: middle" /><label for="checkbox_htmlword_structure"><b><?php echo $strStructure; ?></b></label><br />
+                    </td></tr>
+                   <tr><td bgcolor="<?php echo $cfg['BgcolorOne']; ?>">
+                    <input type="checkbox" name="htmlword_data" value="data" id="checkbox_htmlword_data" <?php PMA_exportCheckboxCheck('htmlword_data'); ?> onclick="if (!this.checked &amp;&amp; (!getElement('checkbox_htmlword_structure') || !getElement('checkbox_htmlword_structure').checked)) return false; else return true;" style="vertical-align: middle" /><label for="checkbox_htmlword_data"><b><?php echo $strData; ?>:</b></label><br />
+                <table border="0" cellspacing="1" cellpadding="0">
+                       <tr>
+                           <td>
+                            &nbsp;&nbsp;&nbsp;&nbsp;<?php echo $strReplaceNULLBy; ?>&nbsp;
+                        </td>
+                        <td>
+                            <input type="text" name="htmlword_replace_null" size="20" value="<?php echo $cfg['Export']['htmlword_null']; ?>" class="textfield" />
+                        </td>
+                    </tr>
+                    <tr>
+                        <td>
+                            &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="htmlword_shownames" value="yes" id="checkbox_dump_htmlword_shownames" <?php PMA_exportCheckboxCheck('htmlword_columns'); ?> /><label for="checkbox_dump_htmlword_shownames"><?php echo $strPutColNames; ?></label>
+                        </td>
+                    </tr>
+                </table>
+                    </td></tr>
+               </table>
+            </div>
+
+
 <?php if ($xls) { ?>
             <!-- Native Excel options -->
             <div id="xls_options">
@@ -519,8 +595,7 @@ if (!$hide_structure) { ?>
                     </tr>
                     <tr>
                         <td>
-                            <input type="checkbox" name="xls_shownames" value="yes" id="checkbox_dump_xls_shownames" <?php PMA_exportCheckboxCheck('xls_columns'); ?> />
-                            <label for="checkbox_dump_xls_shownames"><?php echo $strPutColNames; ?></label>
+                            <input type="checkbox" name="xls_shownames" value="yes" id="checkbox_dump_xls_shownames" <?php PMA_exportCheckboxCheck('xls_columns'); ?> /><label for="checkbox_dump_xls_shownames"><?php echo $strPutColNames; ?></label>
                         </td>
                     </tr>
                 </table>
@@ -565,17 +640,14 @@ if (isset($table) && !empty($table) && !isset($num_tables)) {
         <table width="100%" border="0" cellpadding="3" cellspacing="1">
         <tr>
             <th align="left">
-            <input type="checkbox" name="asfile" value="sendit" id="checkbox_dump_asfile" <?php PMA_exportCheckboxCheck('asfile'); ?> style="vertical-align: middle" />
-            <label for="checkbox_dump_asfile"><b><?php echo $strSend; ?></b></label>
+            <input type="checkbox" name="asfile" value="sendit" id="checkbox_dump_asfile" <?php PMA_exportCheckboxCheck('asfile'); ?> style="vertical-align: middle" /><label for="checkbox_dump_asfile"><b><?php echo $strSend; ?></b></label>
             </th>
         </tr>
         <tr>
             <td bgcolor="<?php echo $cfg['BgcolorOne']; ?>">
                 <?php if (isset($cfg['SaveDir']) && !empty($cfg['SaveDir'])) { ?>
-                &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="onserver" value="saveit" id="checkbox_dump_onserver"  onclick="getElement('checkbox_dump_asfile').checked = true;" <?php PMA_exportCheckboxCheck('onserver'); ?> style="vertical-align: middle" />
-                <label for="checkbox_dump_onserver"><?php echo sprintf($strSaveOnServer, htmlspecialchars($cfg['SaveDir'])); ?></label>,<br />
-                &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="onserverover" value="saveitover" id="checkbox_dump_onserverover"  onclick="getElement('checkbox_dump_onserver').checked = true;getElement('checkbox_dump_asfile').checked = true;" <?php PMA_exportCheckboxCheck('onserver_overwrite'); ?> style="vertical-align: middle" />
-                <label for="checkbox_dump_onserverover"><?php echo $strOverwriteExisting; ?></label>
+                &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="onserver" value="saveit" id="checkbox_dump_onserver"  onclick="getElement('checkbox_dump_asfile').checked = true;" <?php PMA_exportCheckboxCheck('onserver'); ?> style="vertical-align: middle" /><label for="checkbox_dump_onserver"><?php echo sprintf($strSaveOnServer, htmlspecialchars($cfg['SaveDir'])); ?></label>,<br />
+                &nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="onserverover" value="saveitover" id="checkbox_dump_onserverover"  onclick="getElement('checkbox_dump_onserver').checked = true;getElement('checkbox_dump_asfile').checked = true;" <?php PMA_exportCheckboxCheck('onserver_overwrite'); ?> style="vertical-align: middle" /><label for="checkbox_dump_onserverover"><?php echo $strOverwriteExisting; ?></label>
                 <br />
                 <?php } ?>
 
@@ -587,26 +659,25 @@ if (isset($table) && !empty($table) && !isset($num_tables)) {
                         if (isset($_COOKIE) && !empty($_COOKIE['pma_db_filename_template'])) {
                             echo $_COOKIE['pma_db_filename_template'];
                         } else {
-                            echo '__DB__';
+                            echo $GLOBALS['cfg']['Export']['file_template_database'];
                         }
                     } elseif ($export_type == 'table') {
                         if (isset($_COOKIE) && !empty($_COOKIE['pma_table_filename_template'])) {
                             echo $_COOKIE['pma_table_filename_template'];
                         } else {
-                            echo '__TABLE__';
+                            echo $GLOBALS['cfg']['Export']['file_template_table'];
                         }
                     } else {
                         if (isset($_COOKIE) && !empty($_COOKIE['pma_server_filename_template'])) {
                             echo $_COOKIE['pma_server_filename_template'];
                         } else {
-                            echo '__SERVER__';
+                            echo $GLOBALS['cfg']['Export']['file_template_server'];
                         }
                     }
                     echo '" ';
                 ?> style="vertical-align: middle" />
                 (
-                <input type="checkbox" name="remember_template" id="checkbox_remember_template" <?php PMA_exportCheckboxCheck('remember_file_template'); ?> style="vertical-align: middle" />
-                <label for="checkbox_remember_template"><?php echo $strFileNameTemplateRemember; ?></label>
+                <input type="checkbox" name="remember_template" id="checkbox_remember_template" <?php PMA_exportCheckboxCheck('remember_file_template'); ?> style="vertical-align: middle" /><label for="checkbox_remember_template"><?php echo $strFileNameTemplateRemember; ?></label>
                 )*
 
                 <?php
@@ -616,19 +687,14 @@ if (isset($table) && !empty($table) && !isset($num_tables)) {
                     echo "\n";
 
                     $temp_charset = reset($cfg['AvailableCharsets']);
-                    echo '<select id="select_charset_of_file" name="charset_of_file" size="1">' . "\n"
-                            . '                <option value="' . $temp_charset . '"';
-                    if ($temp_charset == $charset) {
-                        echo ' selected="selected"';
-                    }
-                    echo '>' . $temp_charset . '</option>' . "\n";
-                    while ($temp_charset = next($cfg['AvailableCharsets'])) {
+                    echo '<select id="select_charset_of_file" name="charset_of_file" size="1">' . "\n";
+                    foreach($cfg['AvailableCharsets'] as $key => $temp_charset) {
                         echo '                <option value="' . $temp_charset . '"';
-                        if ($temp_charset == $charset) {
+                        if ((empty($cfg['Export']['charset']) && $temp_charset == $charset) || $temp_charset == $cfg['Export']['charset']) {
                             echo ' selected="selected"';
                         }
                         echo '>' . $temp_charset . '</option>' . "\n";
-                    } // end while
+                    } // end foreach
                     echo '            </select>';
                 } // end if
                 echo "\n";
